"""
This is the lower level REST client for Feldera.

This is a thin wrapper around the Feldera REST API.

It is recommended to use the higher level abstractions in the `feldera` package,
instead of using the REST client directly.

"""

from feldera.rest.feldera_client import FelderaClient as FelderaClient



import unittest

from feldera.testutils import datafusionize


class TestDatafusionize(unittest.TestCase):
    def test_datafusionize(self):
        # Test SORT_ARRAY replacement
        query = "SELECT SORT_ARRAY(col1) FROM table1"
        result = datafusionize(query)
        assert "array_sort(col1)" in result

        # Test TRUNCATE replacement
        query = "SELECT TRUNCATE(value, 2) FROM table2"
        result = datafusionize(query)
        assert "trunc(value, 2)" in result

        # Test TIMESTAMP_TRUNC replacement
        query = "SELECT TIMESTAMP_TRUNC(MAKE_TIMESTAMP(2023, 1, 15, 10, 30, 0), DAY) FROM table3"
        result = datafusionize(query)
        assert "DATE_TRUNC('DAY', TO_TIMESTAMP(2023, 1, 15, 10, 30, 0))" in result

        query = "TIMESTAMP_TRUNC(MAKE_TIMESTAMP(order_group_last_activity_time), hour) AS window_start_time,"
        result = datafusionize(query)
        assert (
            "DATE_TRUNC('hour', TO_TIMESTAMP(order_group_last_activity_time)) AS window_start_time,"
            in result
        )

        # Test case insensitive matching
        query = "SELECT sort_array(col) FROM table WHERE truncate(val) > 0"
        result = datafusionize(query)
        assert "array_sort(col)" in result
        assert "trunc(val)" in result


if __name__ == "__main__":
    unittest.main()



import logging
import os
from typing import Optional

from feldera.rest._helpers import requests_verify_from_env


class Config:
    """
    :class:`.FelderaClient` configuration, which includes authentication information
    and the address of the Feldera API the client will interact with.
    """

    def __init__(
        self,
        url: Optional[str] = None,
        api_key: Optional[str] = None,
        version: Optional[str] = None,
        timeout: Optional[float] = None,
        connection_timeout: Optional[float] = None,
        requests_verify: Optional[bool | str] = None,
        health_recovery_timeout: Optional[int] = None,
    ) -> None:
        """
        See documentation of the `FelderaClient` constructor for the other arguments.

        :param version: (Optional) Version of the API to use.
            Default: `v0`.
        :param health_recovery_timeout: (Optional) Maximum time in seconds to wait for cluster health recovery after a 502 error.
            Default: `300` (5 minutes).
        """
        self.url: str = url or os.environ.get("FELDERA_HOST") or "http://localhost:8080"
        self.api_key: Optional[str] = api_key or os.environ.get("FELDERA_API_KEY")
        self.version: str = version or "v0"
        self.timeout: Optional[float] = timeout
        self.connection_timeout: Optional[float] = connection_timeout
        self.health_recovery_timeout: int = health_recovery_timeout or 300
        env_verify = requests_verify_from_env()
        self.requests_verify: bool | str = (
            requests_verify if requests_verify is not None else env_verify
        )

        if self.requests_verify is False:
            logging.warning("Feldera client: TLS verification is disabled!")
